@@ -18,9 +18,10 @@
 */
 
 #include "connectedappmodel.h"
+#include "kwalletmanager_debug.h"
 
 #include <kwallet.h>
-#include <QDebug>
+
 
 ConnectedAppModel::ConnectedAppModel(KWallet::Wallet *wallet):
     QStandardItemModel(),
@@ -36,32 +37,32 @@ void ConnectedAppModel::refresh()
 
     _connectedApps = KWallet::Wallet::users(_wallet->walletName());
     int row = 0;
-    Q_FOREACH(QString appName, _connectedApps) {
+    for (const QString &appName : qAsConst(_connectedApps)) {
         // for un unknown reason, kwalletd returs empty strings so lets avoid inserting them
         // FIXME: find out why kwalletd returns empty strings here
-        if (appName.length() > 0) {
+        if (!appName.isEmpty()) {
             QStandardItem *item = new QStandardItem(appName);
             item->setEditable(false);
             setItem(row, 0, item);
             // this item will be hidden by the disconnect button, see below setIndexWidget call
-            setItem(row, 1, new QStandardItem("dummy"));
+            setItem(row, 1, new QStandardItem(QStringLiteral("dummy")));
             _connectedAppsIndexMap.insert(appName, QPersistentModelIndex(index(row, 0)));
             row++;
         }
     }
 }
 
-void ConnectedAppModel::removeApp(QString appName)
+void ConnectedAppModel::removeApp(const QString &appName)
 {
     if (_connectedAppsIndexMap.contains(appName)) {
         QPersistentModelIndex idx = _connectedAppsIndexMap[appName];
         if (idx.isValid()) {
             if (!removeRow(idx.row())) {
-                qDebug() << "Remove row failed for app " << appName;
+                qCDebug(KWALLETMANAGER_LOG) << "Remove row failed for app " << appName;
             }
         }
     } else {
-        qDebug() << "Attempting to remove unknown application " << appName;
+        qCDebug(KWALLETMANAGER_LOG) << "Attempting to remove unknown application " << appName;
     }
 }
 
